@@ -1,6 +1,6 @@
-/* 
+/*
 *      Copyright (c) 2020 Robert Shaw
-*		This file is a part of Libecpint.
+       This file is a part of Libecpint.
 *
 *      Permission is hereby granted, free of charge, to any person obtaining
 *      a copy of this software and associated documentation files (the
