@@ -3,7 +3,7 @@
 #include <iostream>
 
 using namespace libecpint;
-
+#ifdef HAS_PUGIXML
 
 class ECPBasisTest : public testing::Test {
 protected:
@@ -30,4 +30,6 @@ TEST_F(ECPBasisTest, AddFromFile) {
 	EXPECT_EQ(basis.getMaxL(), 3);
 	EXPECT_EQ(basis.getN(), 2);
 	EXPECT_EQ(basis.getECPCore(33), 28);
-}
\ No newline at end of file
+}
+
+#endif
